@@ -3,18 +3,23 @@ from .pipeline import Pipeline
 from .pumpbuilder import PumpBuilder
 from .abc.source import Source
 from .abc.source import TriggerSource
-from .abc.matrix import MatrixABC
 from .abc.sink import Sink
 from .abc.processor import Processor
 from .abc.generator import Generator
 from .abc.connection import Connection
+
 from .exception import ProcessingError
-from .abc.lookup import Lookup, MappingLookup, DictionaryLookup
+from .abc.lookup import Lookup
+from .abc.lookup import MappingLookup
+from .abc.lookup import DictionaryLookup
 from .fileloader import load_json_file
+from .matrix.matrix import Matrix, NamedMatrix
+
+from .abc.anomaly import Anomaly
 
 from .__version__ import __version__, __build__
 
-__all__ = [
+__all__ = (
 	"BSPumpApplication",
 	"Pipeline",
 	"PumpBuilder",
@@ -24,9 +29,17 @@ __all__ = [
 	"Processor",
 	"Generator",
 	"Connection",
+
 	"ProcessingError",
 	"Lookup",
 	"MappingLookup",
 	"DictionaryLookup",
 	"load_json_file",
-]
+	"Matrix",
+	"NamedMatrix",
+
+	"Anomaly",
+
+	"__version__",
+	"__build__",
+)
