@@ -7,15 +7,20 @@ from .geomatrix import GeoMatrix
 from .timewindowmatrix import TimeWindowMatrix
 from .sessionmatrix import SessionMatrix
 from .latch import LatchAnalyzer
+from .analyzingsource import AnalyzingSource
+from .threshold import ThresholdAnalyzer
 
-__all__ = [
+
+__all__ = (
 	'Analyzer',
-	'TimeDriftAnalyzer',
 	'TimeWindowAnalyzer',
+	'TimeDriftAnalyzer',
 	'SessionAnalyzer',
 	'GeoAnalyzer',
 	'GeoMatrix',
 	'TimeWindowMatrix',
 	'SessionMatrix',
 	'LatchAnalyzer',
-]
+	'AnalyzingSource',
+	'ThresholdAnalyzer',
+)
