@@ -1,2 +1,8 @@
 from .smtpsink import SmtpSink
 from .smtpconnection import SmtpConnection
+
+
+__all__ = (
+	'SmtpSink',
+	'SmtpConnection',
+)
