@@ -4,3 +4,7 @@ from .test_latch import *
 from .test_timedriftanalyzer import *
 from .test_timewindowanalyzer import *
 from .test_sessionanalyzer import *
+from .test_geo_matrix import *
+from .test_session_matrix import *
+from .test_time_window_matrix import *
+
